
# Type: subject




URI: [https://example.com/test65/subject](https://example.com/test65/subject)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children

 *  [child of named thing➞subject](child_of_named_thing_subject.md)

## Used by

 * [ChildOfNamedThing](ChildOfNamedThing.md)
 * [NamedThing](NamedThing.md)
